@@ -2,11 +2,12 @@ package Net::Config;
 
 require Exporter;
 use vars qw(@ISA @EXPORT %NetConfig $VERSION $CONFIGURE $LIBNET_CFG);
+use Socket qw(inet_aton inet_ntoa);
 use strict;
 
 @EXPORT  = qw(%NetConfig);
 @ISA     = qw(Net::LocalCfg Exporter);
-$VERSION = "1.02";
+$VERSION = "1.03";
 
 eval { local $SIG{__DIE__}; require Net::LocalCfg };
 
@@ -67,7 +68,7 @@ sub requires_firewall {
 	foreach (@$list) {
 	    my($net,$bits) = (m#^(\d+\.\d+\.\d+\.\d+)/(\d+)$#) or next;
 	    my $mask = ~0 << (32 - $bits);
-	    my $addr = unpack("N",pack("C*",split(".",$host)));
+	    my $addr = unpack("N",pack("C*",split(/\./,$host)));
 
 	    return 0 if (($addr & $mask) == ($quad & $mask));
 	}
